@@ -53,7 +53,7 @@ struct ECalBackendExchangePrivate {
 #define PARENT_TYPE E_TYPE_CAL_BACKEND_SYNC
 static GObjectClass *parent_class = NULL;
 
-#define d(x) x
+#define d(x)
 
 static ECalBackendSyncStatus
 is_read_only (ECalBackendSync *backend, EDataCal *cal, gboolean *read_only)
@@ -302,11 +302,11 @@ open_calendar (ECalBackendSync *backend, EDataCal *cal, gboolean only_if_exists,
 static ECalBackendSyncStatus
 remove_calendar (ECalBackendSync *backend, EDataCal *cal)
 {
-	ECalBackendExchange *be = E_CAL_BACKEND_EXCHANGE (backend);
-	E2kHTTPStatus status;
-	
 	d(printf("ecbe_remove_calendar(%p, %p)\n", backend, cal));
-	
+	return GNOME_Evolution_Calendar_PermissionDenied;
+
+	/* FIXME: Deleting calendar/tasks from respective views */
+#if 0
 	status = e_folder_exchange_delete (be->folder, NULL);
 	if (E2K_HTTP_STATUS_IS_SUCCESSFUL (status))
 		return GNOME_Evolution_Calendar_Success;
@@ -314,6 +314,7 @@ remove_calendar (ECalBackendSync *backend, EDataCal *cal)
 		return GNOME_Evolution_Calendar_PermissionDenied;
 	else
 		return GNOME_Evolution_Calendar_OtherError;
+#endif
 }
 
 static void
@@ -528,9 +529,7 @@ static ECalBackendSyncStatus
 discard_alarm (ECalBackendSync *backend, EDataCal *cal,
 	       const char *uid, const char *auid)
 {
-	d(printf("ecbe_discard_alarm(%p, %p, uid=%s, auid=%s)\n", backend, cal, uid, auid));
-
-	/* FIXME */
+	/* To be called from the Calendar derived class */
 	return GNOME_Evolution_Calendar_OtherError;
 }
 
